@@ -1,9 +1,9 @@
 ROLES = {
-    "TOP": "top",
-    "JUNGLE": "jungle",
-    "MID": "mid",
-    "BOTTOM": "adc",
-    "SUPPORT": "support",
+    "top": "top",
+    "jungle": "jungle",
+    "mid": "mid",
+    "bottom": "adc",
+    "utility": "support",
 }
 
 SPELLS = {
@@ -26,3 +26,8 @@ SPELLS = {
     "Summoner_UltBookPlaceholder": "54",
     "Summoner_UltBookSmitePlaceholder": "55",
 }
+
+
+RESPONSE_ERROR_CODE = 400
+
+MIN_PY_VER = 10
